@@ -63,7 +63,7 @@ except Exception as ex:
     stdfile.close()
   errtrace = traceback.format_exc()
   err = "Error " + str(exc)
-  data = json.dumps({"error": err, "trace": str(errtrace)}, default=json_util.default)
+  data = json.dumps({"error": str(errtrace), "trace": str(errtrace)}, default=json_util.default)
   sys.stdout.write(data)
 
 """
\ No newline at end of file
